from distutils.core import setup
setup(
  name = 'iplibrary',
  packages = ['iplibrary'],
  version = '1.1',
  description = 'Python library to get the users IP.',
  author = 'Vilhelm Prytz',
  author_email = 'contact@mrkakisen.net',
  url = 'https://github.com/MrKaKisen/python-ip-library',
  download_url = 'https://github.com/MrKaKisen/python-ip-library/archive/1.1.tar.gz',
  keywords = ['ip', 'iplibrary', 'getIP'],
  classifiers = [],
)
